Class: FFI::Clang::IndexAction::Container

Inherits:
Object
  • Object
show all
Defined in:
lib/ffi/clang/index_action.rb

Overview

Represents an entity container reported by the indexing API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(info, translation_unit) ⇒ Container

Build a container wrapper from a libclang container info pointer.



49
50
51
# File 'lib/ffi/clang/index_action.rb', line 49

def initialize(info, translation_unit)
	@cursor = Cursor.new(info[:cursor], translation_unit)
end

Instance Attribute Details

#cursorObject (readonly)

Returns the value of attribute cursor.



44
45
46
# File 'lib/ffi/clang/index_action.rb', line 44

def cursor
  @cursor
end