Class: FFI::Clang::IndexAction::CallbackAdapter
- Inherits:
-
Object
- Object
- FFI::Clang::IndexAction::CallbackAdapter
- Defined in:
- lib/ffi/clang/index_action.rb
Overview
Adapter object that owns the callback procs for a single indexing run.
Instance Attribute Summary collapse
-
#callbacks ⇒ Object
readonly
Returns the value of attribute callbacks.
Instance Method Summary collapse
-
#aborted? ⇒ Boolean
Check if indexing was aborted by the user callback.
-
#initialize(translation_unit, &block) ⇒ CallbackAdapter
constructor
Build callbacks that snapshot libclang indexing payloads.
Constructor Details
#initialize(translation_unit, &block) ⇒ CallbackAdapter
Build callbacks that snapshot libclang indexing payloads.
433 434 435 436 437 438 439 |
# File 'lib/ffi/clang/index_action.rb', line 433 def initialize(translation_unit, &block) @translation_unit = translation_unit @block = block @aborted = false @callbacks = Lib::IndexerCallbacks.new initialize_callbacks end |
Instance Attribute Details
#callbacks ⇒ Object (readonly)
Returns the value of attribute callbacks.
428 429 430 |
# File 'lib/ffi/clang/index_action.rb', line 428 def callbacks @callbacks end |
Instance Method Details
#aborted? ⇒ Boolean
Check if indexing was aborted by the user callback.
443 444 445 |
# File 'lib/ffi/clang/index_action.rb', line 443 def aborted? @aborted end |