Class: FFI::Clang::IndexAction::Container
- Inherits:
-
Object
- Object
- FFI::Clang::IndexAction::Container
- Defined in:
- lib/ffi/clang/index_action.rb
Overview
Represents an entity container reported by the indexing API.
Instance Attribute Summary collapse
-
#cursor ⇒ Object
readonly
Returns the value of attribute cursor.
Instance Method Summary collapse
-
#initialize(info, translation_unit) ⇒ Container
constructor
Build a container wrapper from a libclang container info pointer.
Constructor Details
Instance Attribute Details
#cursor ⇒ Object (readonly)
Returns the value of attribute cursor.
44 45 46 |
# File 'lib/ffi/clang/index_action.rb', line 44 def cursor @cursor end |